==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىش</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>خاتىرىنى تازىلاش</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>يېڭىلاش</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>بۇ خاتىرىنى راستلا ئۆچۈرمەكچىمۇ؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>جەزملەش</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>ھەممىسى</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>بۈگۈن</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3كۈن</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 ھەپتە</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 ئاي</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 ئاي</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">چىقىرىش</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>چىقىرىش</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>ھەممىسى</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>جىددىي</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>ئېغىر ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>ئېغىر</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خاتالىق</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>دىققەت</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>سىناپ تەڭشەش</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>كىرىش</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>قوزغىتىش</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>ئىنتايىن ئېغىر</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>ئىز قوغلاش</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>چىقىرىۋاتىدۇ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>چىقىرىلدى</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>ھۆججەتننى چىقىرالمىدى</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>ھۆججەت چىقىرىش</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>دەۋرىيلىكى:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>دەرىجىسى:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>ئەپ تىزىملىكى:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>ھالىتى:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>پائالىيەت تىپى:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>مەشغۇلات:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>قوزغىتىش خاتىرىسى</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>تاقاش خاتىرىسى</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>كىرىش خاتىرىسى</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>سىناپ تەڭشەش</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خاتالىق</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>جىددىي</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>ئېغىر ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>ئېغىر</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>دىققەت</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>ئىز قوغلاش</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>ئىنتايىن ئېغىر</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>خاتىرە ھۆججەت قۇرۇق</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>خاتىرە كۆرگۈچ</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>خاتىرە يىغىش قورالى سىستېما خاتىرىسىنى كۆرسىتىدىغان كىچىك قورال.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>ئىزدەش نەتىجىسى يوق</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>ئىزدەش</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>دەرىجىسى</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>جەريان</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>ۋاقىت</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <source>User</source>
        <translation>ئىشلەتكۈچى نامى</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>مەنبە</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>مەشغۇلات</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>ھالىتى</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>پائالىيەت تىپى</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>كىرىش نامى</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>دەرىجىسى:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>جەريان:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>ۋاقىت:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>ئۇچۇر:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>ۋاقىت</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>سىستېما خاتىرىسى</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>ئىچكى يادرو خاتىرىسى</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>قوزغىتىش خاتىرىسى</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg خاتىرىسى</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin خاتىرىسى</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg خاتىرىسى</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>ئەپلەر خاتىرىسى</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>ئېچىش-تاقاش مەشغۇلاتى</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf خاتىرىسى</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىش</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>خاتىرىنى تازىلاش</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>يېڭىلاش</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>بۇ خاتىرىنى راستلا ئۆچۈرمەكچىمۇ؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>جەزملەش</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>ھەممىسى</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>بۈگۈن</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3كۈن</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 ھەپتە</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 ئاي</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 ئاي</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>چىقىرىش</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>ھەممىسى</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>جىددىي</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>ئېغىر ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>ئېغىر</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خاتالىق</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>دىققەت</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>سىناپ تەڭشەش</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>كىرىش</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>قوزغىتىش</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>ئىنتايىن ئېغىر</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>ئىز قوغلاش</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>سالاھىيەت پەرقلەندۈرۈش</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>ئۆز ئالدىغا زىيارەت قىلىشنى كونتروللاش</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>مەجبۇرىي زىيارەتنى قىلىشنى كونتروللاش</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>يىراقتىن ئۇلاش</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>ھۆججەت تەكشۈرۈش</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>باشقا</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>چىقىرىۋاتىدۇ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>چىقىرىلدى</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>ھۆججەتننى چىقىرالمىدى</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>چىقىرىدىغان مۇندەرىجىنى ئىشلەتكىلى بولمايدۇ، باشقا مۇندەرىجە تاللاپ مەشغۇلات قىلىڭ</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>ھۆججەت چىقىرىش</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>دەۋرىيلىكى:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>دەرىجىسى:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>ھالىتى:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>پائالىيەت تىپى:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>مەشغۇلات:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>قوزغىتىش خاتىرىسى</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>تاقاش خاتىرىسى</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>كىرىش خاتىرىسى</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>تەكشۈرۈش تىپى:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>ئەپ:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>بالا مودېل:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>سىناپ تەڭشەش</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خاتالىق</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>جىددىي</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>ئېغىر ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>ئېغىر</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>دىققەت</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>ئىز قوغلاش</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>ئىنتايىن ئېغىر</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>خاتىرە ھۆججەت قۇرۇق</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>خاتىرە كۆرگۈچ</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>خاتىرە يىغىش قورالى سىستېما خاتىرىسىنى كۆرسىتىدىغان كىچىك قورال.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>ئىزدەش نەتىجىسى يوق</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>ئىزدەش</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>دەرىجىسى</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>جەريان</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>ۋاقىت</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <source>User</source>
        <translation>ئىشلەتكۈچى نامى</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>مەنبە</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>مەشغۇلات</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>ھالىتى</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>پائالىيەت تىپى</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>كىرىش نامى</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>دەرىجىسى:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>جەريان:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>ۋاقىت:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>ئۇچۇر:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>ھۆججەت نامى</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>ئۆزگەرتكەن ۋاقىت:</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>سىگنال</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>پىروگرامما</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>يادرولۇق ھۆججەت</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>ئىشلەتكۈچى</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>پىروگرامما</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>ۋاقىت</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>سىستېما خاتىرىسى</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>ئىچكى يادرو خاتىرىسى</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>قوزغىتىش خاتىرىسى</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg خاتىرىسى</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin خاتىرىسى</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg خاتىرىسى</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>ئەپلەر خاتىرىسى</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>ئېچىش-تاقاش مەشغۇلاتى</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf خاتىرىسى</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>باشقا كۈندىلىك خاتىرە</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>كۈندىلىك خاتىرە بەلگىلەش</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>تەكشۈرۈش خاتىرىسى</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>گۇم بولۇش خاتىرىسى</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>ئۇچۇرنى ئالالمىدى، systemd-coredump قاچىلاڭ.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>كۆرۈش ھوقۇقى يوق</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>نۆۋەتتىكى سىستېما بىخەتەرلىك دەرىجىسى: يۇقىرى
تەكشۈرگۈچى باشقۇرغۇچىلا تەكشۈرۈش خاتىرىسىنى كۆرەلەيدۇ</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>خاتىرىنى بەلگىلىگەن مۇندەرىجىگە چىقىرىش</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>چىقىرىش مۇندەرىجىسى</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>خاتىرە تۈرى بويىچە چىقىرىش</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>خاتىرە تۈرى</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>خاتىرىنى ئۆز ئالدىغا ئاچقان ئەپ بويىچە چىقىرىش</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>ئۆز ئالدىغا ئاچقان  ئەپ نامى</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>خاتىرىنى ۋاقىت دەۋرىيلىكى بويىچە چىقىرىش</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>دەۋرىيلىكى</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>خاتىرىنى تەڭشەش-سىناش دەرىجىسى بويىچە چىقىرىش</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>تەڭشەش-سىناش دەرىجىسى</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>قوزغىلىش ھالىتى</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>قوزغىلىش خاتىرىسىنى ھالىتى بويىچە چىقىرىش(klu)</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>ئېچىش-تاقاش خاتىرىسى/تەكشۈرۈش خاتىرىسىنى مەشغۇلات تۈرى بويىچە چىقىرىش</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>مەشغۇلات تۈرى</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>خاتىرىنى ھالقىلىق سۆز بويىچە چىقىرىش</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>ھالقىلىق سۆز</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>گۇم بولۇش نۇقتىسىنىڭ ئۇچۇرىنى يوللاش</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>خاتىرىنى بالا مودېل بويىچە چىقىرىش</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>بالا مودېل</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>يېڭىلاش چاستوتىسى</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>ھەر 10 سېكۇنت</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>ھەر 1 مىنۇت</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 مىنۇت</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>يېڭىلىمىسۇن</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>ھەممىنى چىقىرىش</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>ھازىر يېڭىلاش</translation>
    </message>
</context>
</TS>
